@@ -1,10 +1,10 @@
 # ABSTRACT: Driver for the Arabic tagset of the CoNLL 2007 Shared Task.
-# Copyright © 2011, 2014 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2011, 2014, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::AR::Conll2007;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -71,7 +71,7 @@ sub _create_atoms
             # interrogative particle
             'FI' => ['pos' => 'part', 'prontype' => 'int'],
             # negative particle
-            'FN' => ['pos' => 'part', 'negativeness' => 'neg'],
+            'FN' => ['pos' => 'part', 'polarity' => 'neg'],
             # interjection
             'I-' => ['pos' => 'int'],
             # abbreviation
@@ -109,8 +109,8 @@ sub _create_atoms
                                                                                                  'adp'  => 'P-',
                                                                                                  'conj' => 'C-',
                                                                                                  'part' => { 'prontype' => { 'int' => 'FI',
-                                                                                                                             '@'   => { 'negativeness' => { 'neg' => 'FN',
-                                                                                                                                                            '@'   => 'F-' }}}},
+                                                                                                                             '@'   => { 'polarity' => { 'neg' => 'FN',
+                                                                                                                                                        '@'   => 'F-' }}}},
                                                                                                  'int'  => 'I-',
                                                                                                  'punc' => 'G-',
                                                                                                  '@'    => '_' }},
@@ -151,15 +151,15 @@ sub _create_atoms
     # DEFINITENESS ####################
     $atoms{Defin} = $self->create_simple_atom
     (
-        'intfeature' => 'definiteness',
+        'intfeature' => 'definite',
         'simple_decode_map' =>
         {
             # definite
             'D' => 'def',
             # indefinite
             'I' => 'ind',
-            # reduced
-            'R' => 'red',
+            # reduced (construct state)
+            'R' => 'cons',
             # complex
             'C' => 'com'
         }
@@ -581,7 +581,7 @@ Lingua::Interset::Tagset::AR::Conll2007 - Driver for the Arabic tagset of the Co
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -616,7 +616,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
