@@ -8,7 +8,7 @@
 package Lingua::Interset::Tagset::BN::Conll;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -119,7 +119,7 @@ sub _create_atoms
             # negation
             # Example:
             # না (nā = not)
-            'NEG'  => ['pos' => 'part', 'prontype' => 'neg', 'negativeness' => 'neg'],
+            'NEG'  => ['pos' => 'part', 'prontype' => 'neg', 'polarity' => 'neg'],
             # postpositions
             # Examples:
             # সহ (saha = with)
@@ -915,7 +915,7 @@ Lingua::Interset::Tagset::BN::Conll - Driver for the Bengali tagset of the ICON
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -959,7 +959,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
