@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::CA::Conll2009;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -136,7 +136,7 @@ sub _create_atoms
             # types of adverbs
             ###!!! In theory, non-negative adverbs should have postype=general. In practice, there are only two occurrences of this feature
             ###!!! while all other adverbs have empty postype. Therefore I removed postype=general from the list of known tags.
-            'negative'      => ['negativeness' => 'neg'], # no; main POS is adverb; in other tagsets it could be negative particle
+            'negative'      => ['polarity' => 'neg'], # no; main POS is adverb; in other tagsets it could be negative particle
             # prepositions
             'preposition'   => ['adpostype' => 'prep'], # all prepositions (pos=s) have also postype=preposition; it should not occur with other parts of speech than "s"
             # types of conjunctions
@@ -175,7 +175,7 @@ sub _create_atoms
                                                     'preppron' => 'preposition' }},
                        'conj' => { 'conjtype' => { 'coor' => 'coordinating',
                                                    'sub'  => 'subordinating' }},
-                       '@'    => { 'negativeness' => { 'neg' => 'negative' }}}
+                       '@'    => { 'polarity' => { 'neg' => 'negative' }}}
         }
     );
     # POS FUNCTION ####################
@@ -248,11 +248,11 @@ sub _create_atoms
     # POLITENESS ####################
     $atoms->{polite} = $self->create_simple_atom
     (
-        'intfeature' => 'politeness',
+        'intfeature' => 'polite',
         'simple_decode_map' =>
         {
             # Used only for the two polite 2nd person pronouns, "vost&egra;" (sing) and "vost&egra;s" (plur).
-            'yes' => 'pol'
+            'yes' => 'form'
         }
     );
     # POSSESSOR NUMBER ####################
@@ -830,7 +830,7 @@ Lingua::Interset::Tagset::CA::Conll2009 - Driver for the Catalan tagset of the C
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -867,7 +867,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
