@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::CS::Multext;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -37,14 +37,14 @@ sub _create_feature_map
     my $self = shift;
     my %features =
     (
-        'N' => ['pos', 'nountype', 'gender', 'number', 'case', undef, undef, 'animateness'], # definiteness and clitic not used in Czech
-        'A' => ['pos', 'adjtype', 'degree', 'gender', 'number', 'case', undef, undef, 'animateness', 'adjform'], # definiteness and clitic not used in Czech
-        'P' => ['pos', 'prontype', 'person', 'gender', 'number', 'case', 'possnumber', 'possgender', 'clitic', 'referent_type', 'syntactic_type', undef, 'animateness', 'clitic_s'],
-        'M' => ['pos', 'numtype', 'gender', 'number', 'case', 'numform', undef, undef, 'numclass', 'animateness'],
+        'N' => ['pos', 'nountype', 'gender', 'number', 'case', undef, undef, 'animacy'], # definiteness and clitic not used in Czech
+        'A' => ['pos', 'adjtype', 'degree', 'gender', 'number', 'case', undef, undef, 'animacy', 'adjform'], # definiteness and clitic not used in Czech
+        'P' => ['pos', 'prontype', 'person', 'gender', 'number', 'case', 'possnumber', 'possgender', 'clitic', 'referent_type', 'syntactic_type', undef, 'animacy', 'clitic_s'],
+        'M' => ['pos', 'numtype', 'gender', 'number', 'case', 'numform', undef, undef, 'numclass', 'animacy'],
         # The documentation lists only 11 features (including the initial 'V') for Czech verbs.
         # However, the data contains verb tags of up to 14 characters.
         # Most likely, the designers forgot to skip the empty values of definiteness, clitic and case.
-        'V' => ['pos', 'verbtype', 'verbform', 'tense', 'person', 'number', 'gender', 'voice', 'negativeness', undef, undef, undef, 'animateness', 'clitic_s'],
+        'V' => ['pos', 'verbtype', 'verbform', 'tense', 'person', 'number', 'gender', 'voice', 'polarity', undef, undef, undef, 'animacy', 'clitic_s'],
         'R' => ['pos', 'adverb_type', 'degree'],
         'S' => ['pos', 'adpostype', 'adposition_formation', 'case'],
         'C' => ['pos', 'conjtype', undef, undef, undef, undef, 'number', 'person'] # undefined formation, coord type, sub type and clitic
@@ -1550,7 +1550,7 @@ Lingua::Interset::Tagset::CS::Multext - Driver for the Czech tagset of the Multe
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -1579,7 +1579,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
