@@ -1,10 +1,10 @@
 # ABSTRACT: Driver for the shortened Czech tagset of the Prague Spoken Corpus (Pražský mluvený korpus).
-# Copyright © 2009, 2010, 2014 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2009, 2010, 2014, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::CS::Pmkkr;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -38,7 +38,7 @@ sub _create_feature_map
         '4' => ['pos', 'numeral_type', undef, 'style'],
         # sloveso = verb
         # 2. vid 3. valence subjektová 4. valence 5. osoba/číslo 6. způsob/čas/slovesný rod 7. imper./neurč. tvary 8! víceslovnost a rezultativnost 9. jmenný rod 10! zápor 11! styl
-        '5' => ['pos', 'multiwordness_and_resultativity', 'negativeness', 'style'],
+        '5' => ['pos', 'multiwordness_and_resultativity', 'polarity', 'style'],
         # adverbium = adverb
         # 2! druh 3. třída 4. valence/funkce 5. stupeň 6! styl
         '6' => ['pos', 'adverb_type', undef, 'style'],
@@ -410,7 +410,7 @@ Lingua::Interset::Tagset::CS::Pmkkr - Driver for the shortened Czech tagset of t
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -440,7 +440,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
