@@ -1,11 +1,12 @@
 # ABSTRACT: Driver for the German tagset of SMOR (Stuttgart Morphology)
 # Modified by Lefteris Avramidis, based on original script from Dan Zeman <zeman@ufal.mff.cuni.cz>
 # Completed by Dan Zeman.
+# 2017: adapted to Universal Dependencies v2.
 
 package Lingua::Interset::Tagset::DE::Smor;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -225,12 +226,12 @@ sub _create_atoms
             # response particle: bitte, doch, ja, nein, nö, schon
             'Ans' => ['parttype' => 'res'],
             # negative particle: nicht, net
-            'Neg' => ['negativeness' => 'neg']
+            'Neg' => ['polarity' => 'neg']
         },
         'encode_map' =>
         {
             'parttype' => { 'res' => 'Ans',
-                            '@'   => { 'negativeness' => { 'neg' => 'Neg' }}}
+                            '@'   => { 'polarity' => { 'neg' => 'Neg' }}}
         }
     );
     # PUNCTUATION TYPE ####################
@@ -301,7 +302,7 @@ sub _create_atoms
     # DEFINITHEIT / DEFINITENESS ####################
     $atoms{definiteness} = $self->create_simple_atom
     (
-        'intfeature' => 'definiteness',
+        'intfeature' => 'definite',
         'simple_decode_map' =>
         {
             'Def'   => 'def',
@@ -1405,7 +1406,7 @@ Lingua::Interset::Tagset::DE::Smor - Driver for the German tagset of SMOR (Stutt
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -1452,7 +1453,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
