@@ -1,10 +1,10 @@
 # ABSTRACT: Driver for the Stuttgart-Tübingen Tagset of German.
-# Copyright © 2008, 2014 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2008, 2014, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::DE::Stts;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -158,7 +158,7 @@ around BUILDARGS => sub
         'PTKZU'   => ['pos' => 'part', 'parttype' => 'inf'],
         # negation particle / Negationspartikel
         # "nicht"
-        'PTKNEG'  => ['pos' => 'part', 'negativeness' => 'neg'],
+        'PTKNEG'  => ['pos' => 'part', 'polarity' => 'neg'],
         # separated verb prefix / abgetrennter Verbzusatz
         # "[er hört] auf", "[er kommt] herbei"
         'PTKVZ'   => ['pos' => 'part', 'parttype' => 'vbp'],
@@ -237,8 +237,8 @@ around BUILDARGS => sub
                    'part' => { 'parttype' => { 'inf' => 'PTKZU',
                                                'vbp' => 'PTKVZ',
                                                'res' => 'PTKANT',
-                                               '@'   => { 'negativeness' => { 'neg' => 'PTKNEG',
-                                                                              '@'   => 'PTKA' }}}},
+                                               '@'   => { 'polarity' => { 'neg' => 'PTKNEG',
+                                                                          '@'   => 'PTKA' }}}},
                    'int'  => 'ITJ',
                    'punc' => { 'punctype' => { 'comm' => '$,',
                                                'peri' => '$.',
@@ -289,7 +289,7 @@ Lingua::Interset::Tagset::DE::Stts - Driver for the Stuttgart-Tübingen Tagset o
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -320,7 +320,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
