@@ -1,10 +1,10 @@
 # ABSTRACT: Driver for the tagset of the Persian Dependency Treebank (in the CoNLL-X format).
-# Copyright © 2012, 2014 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2012, 2014, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::FA::Conll;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -69,8 +69,8 @@ sub _create_atoms
             # coarse IDEN
             "IDEN\tIDEN"  => ['pos' => 'noun', 'other' => {'nountype' => 'title'}], # imám, dktr, šhíd, síd, áytalláh (titles used with personal names)
             # coarse N: noun
-            "N\tANM"      => ['pos' => 'noun', 'animateness' => 'anim'], # xdá, ksí, ansán, xadáwand, nfr
-            "N\tIANM"     => ['pos' => 'noun', 'animateness' => 'inan'], # sál, kár, írán, rúz, dst
+            "N\tANM"      => ['pos' => 'noun', 'animacy' => 'anim'], # xdá, ksí, ansán, xadáwand, nfr
+            "N\tIANM"     => ['pos' => 'noun', 'animacy' => 'inan'], # sál, kár, írán, rúz, dst
             # coarse PART: particle
             "PART\tPART"  => ['pos' => 'part'], # áyá, ke, mgr, rá, dígr
             # coarse POSNUM: number following a noun
@@ -126,8 +126,8 @@ sub _create_atoms
                                                    'dem' => "PR\tDEMON",
                                                    'int' => "PR\tINTG",
                                                    '@'   => { 'other/nountype' => { 'title' => "IDEN\tIDEN",
-                                                                                    '@'     => { 'animateness' => { 'anim' => "N\tANM",
-                                                                                                                    '@'    => "N\tIANM" }}}}}},
+                                                                                    '@'     => { 'animacy' => { 'anim' => "N\tANM",
+                                                                                                                '@'    => "N\tIANM" }}}}}},
                        'adj'  => { 'prontype' => { 'dem' => "PREM\tDEMAJ",
                                                    'int' => "PREM\tQUAJ",
                                                    'exc' => "PREM\tEXAJ",
@@ -706,7 +706,7 @@ Lingua::Interset::Tagset::FA::Conll - Driver for the tagset of the Persian Depen
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -742,7 +742,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
