@@ -1,11 +1,11 @@
 # ABSTRACT: Driver for the Upper Sorbian tagset of the tagger created by Daniil Sorokin.
 # https://bitbucket.org/magpie/part-of-speech-tagger-for-upper-sorbian/downloads
-# Copyright © 2016 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2016, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::HSB::Sorokin;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -192,16 +192,16 @@ sub _create_atoms
         'surfeature' => 'animacy',
         'decode_map' =>
         {
-            'animate'           => ['animateness' => 'anim'],
-            'animateate'        => ['animateness' => 'anim'],
-            'inanimate,animate' => ['animateness' => ''],
-            'inanimate'         => ['animateness' => 'inan'],
-            'inanimate '        => ['animateness' => 'inan']
+            'animate'           => ['animacy' => 'anim'],
+            'animateate'        => ['animacy' => 'anim'],
+            'inanimate,animate' => ['animacy' => ''],
+            'inanimate'         => ['animacy' => 'inan'],
+            'inanimate '        => ['animacy' => 'inan']
         },
         'encode_map' =>
         {
-            'animateness' => { 'anim' => 'animate',
-                               'inan' => 'inanimate' }
+            'animacy' => { 'anim' => 'animate',
+                           'inan' => 'inanimate' }
         }
     );
     # NUMBER ####################
@@ -519,7 +519,7 @@ Lingua::Interset::Tagset::HSB::Sorokin - Driver for the Upper Sorbian tagset of
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -550,7 +550,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
