@@ -1,11 +1,11 @@
 # ABSTRACT: Driver for the Italian tagset of the CoNLL 2007 Shared Task (derived from the ISST, Italian Syntactic-Semantic Treebank).
-# Copyright © 2011, 2014 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2011, 2014, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 # Copyright © 2011 Loganathan Ramasamy <ramasamy@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::IT::Conll;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -55,9 +55,9 @@ sub _create_atoms
             # AP = possessive determiner (suo, mio, nostro, proprio, tuo, vostro)
             'AP' => ['pos' => 'adj', 'prontype' => 'prs', 'poss' => 'poss'],
             # RD = definite article (il, lo, i, gli, la, le, l')
-            'RD' => ['pos' => 'adj', 'prontype' => 'art', 'definiteness' => 'def'],
+            'RD' => ['pos' => 'adj', 'prontype' => 'art', 'definite' => 'def'],
             # RI = indefinite article (un, uno, una, un')
-            'RI' => ['pos' => 'adj', 'prontype' => 'art', 'definiteness' => 'ind'],
+            'RI' => ['pos' => 'adj', 'prontype' => 'art', 'definite' => 'ind'],
             # PD = demonstrative pronoun (lo, quello, questo, ciò, stesso)
             'PD' => ['pos' => 'noun', 'prontype' => 'dem'],
             # PI = indefinite pronoun (uno, tutto, altro, nessuno, qualcuno)
@@ -116,8 +116,8 @@ sub _create_atoms
                                                    'neg' => 'PI' }},
                        'adj'  => { 'prontype' => { ''    => { 'numtype' => { 'ord' => 'NO',
                                                                              '@'   => 'A' }},
-                                                   'art' => { 'definiteness' => { 'def' => 'RD',
-                                                                                  '@'   => 'RI' }},
+                                                   'art' => { 'definite' => { 'def' => 'RD',
+                                                                              '@'   => 'RI' }},
                                                    'dem' => 'DD',
                                                    'ind' => 'DI',
                                                    'tot' => 'DI',
@@ -509,7 +509,7 @@ Lingua::Interset::Tagset::IT::Conll - Driver for the Italian tagset of the CoNLL
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -542,7 +542,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
