@@ -5,7 +5,7 @@
 package Lingua::Interset::Tagset::MUL::Upos;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -51,7 +51,8 @@ around BUILDARGS => sub
         'ADV'   => ['pos' => 'adv'],
         # auxiliary verb
         'AUX'   => ['pos' => 'verb', 'verbtype' => 'aux'],
-        # coordinating conjunction
+        # coordinating conjunction (CONJ in UD v1, CCONJ since UD v2)
+        'CCONJ' => ['pos' => 'conj', 'conjtype' => 'coor'],
         'CONJ'  => ['pos' => 'conj', 'conjtype' => 'coor'],
         # determiner
         'DET'   => ['pos' => 'adj', 'prontype' => 'prn'],
@@ -94,7 +95,7 @@ around BUILDARGS => sub
                    'adv'  => 'ADV',
                    'adp'  => 'ADP',
                    'conj' => { 'conjtype' => { 'sub' => 'SCONJ',
-                                               '@'   => 'CONJ' }},
+                                               '@'   => 'CCONJ' }},
                    'part' => 'PART',
                    'int'  => 'INTJ',
                    'punc' => 'PUNCT',
@@ -127,6 +128,21 @@ sub decode
 
 
 
+#------------------------------------------------------------------------------
+# Returns reference to list of known tags, useful for testing. The Atom class
+# will generate the list for us but we have to remove CONJ from the list
+# because we do not want to preserve it on the output.
+#------------------------------------------------------------------------------
+sub list
+{
+    my $self = shift;
+    my $list = $self->SUPER::list();
+    my @without_conj = grep {$_ ne 'CONJ'} (@{$list});
+    return \@without_conj;
+}
+
+
+
 1;
 
 __END__
@@ -141,7 +157,7 @@ Lingua::Interset::Tagset::MUL::Upos - Driver for the Universal Part-of-Speech Ta
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -175,7 +191,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
