@@ -1,5 +1,5 @@
 # ABSTRACT: Driver for the tagset of the Romanian Dependency Treebank (RDT).
-# Copyright © 2015 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2015, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 # Copyright © 2011 Martin Popel <popel@ufal.mff.cuni.cz>
 # Brief tagset documentation in $TMT_ROOT/share/data/resources/treebanks/ro/2008_calacean.pdf
 # Useful resource http://dexonline.ro
@@ -16,7 +16,7 @@
 package Lingua::Interset::Tagset::RO::Rdt;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -57,13 +57,13 @@ around BUILDARGS => sub
         'adjectiv'           => ['pos' => 'adj'],
         'adverb'             => ['pos' => 'adv'],
         # cel (demonstrative article, used only before adjectives "cel bun")
-        'art. dem.'          => ['pos' => 'adj', 'prontype' => 'dem', 'definiteness' => 'def'],
+        'art. dem.'          => ['pos' => 'adj', 'prontype' => 'dem', 'definite' => 'def'],
         # lui (definite article, used only in possessive constructions with male gender)
-        'art. hot.'          => ['pos' => 'adj', 'prontype' => 'art', 'definiteness' => 'def', 'poss' => 'poss', 'gender' => 'masc'],
+        'art. hot.'          => ['pos' => 'adj', 'prontype' => 'art', 'definite' => 'def', 'poss' => 'poss', 'gender' => 'masc'],
         # al, a, ai, ale (genitival/possessive article)
         'art. poses.'        => ['pos' => 'adj', 'prontype' => 'art', 'poss' => 'poss'],
         # o, un, niște
-        'art. nehot.'        => ['pos' => 'adj', 'prontype' => 'art', 'definiteness' => 'ind'],
+        'art. nehot.'        => ['pos' => 'adj', 'prontype' => 'art', 'definite' => 'ind'],
         'conj. aux.'         => ['pos' => 'conj', 'conjtype' => 'sub'],
         'conj. coord.'       => ['pos' => 'conj', 'conjtype' => 'coor'],
         'numeral'            => ['pos' => 'num'],
@@ -76,8 +76,8 @@ around BUILDARGS => sub
         'verb'               => ['pos' => 'verb', 'verbform' => 'fin'],
         # a, au, fost, fi, vor, fie, este, sunt
         'verb aux.'          => ['pos' => 'verb', 'verbtype' => 'aux'],
-        # fi (a fi = infinitive to be), cântând (transgressive, note that in Romainan it is called "gerunziu", but it is not a gerund like "doing" in English)
-        'verb nepred.'       => ['pos' => 'verb', 'verbform' => 'inf|trans'],
+        # fi (a fi = infinitive to be), cântând (converb/transgressive, note that in Romainan it is called "gerunziu", but it is not a gerund like "doing" in English)
+        'verb nepred.'       => ['pos' => 'verb', 'verbform' => 'inf|conv'],
         # Due to inconsistent annotation, the following tags appear only in the test set :-(
         'verb la participiu' => ['pos' => 'verb', 'verbform' => 'part'],
         # iluminat (tagged as 'verb nepred.' in the rest of RDT)
@@ -94,20 +94,20 @@ around BUILDARGS => sub
                                                                         '@'      => 'pronume' }}}},
                    'adj'  => { 'prontype' => { ''    => { 'verbform' => { 'part' => 'adj. particip.',
                                                                           '@'    => 'adjectiv' }},
-                                               'dem' => { 'definiteness' => { 'def' => 'art. dem.',
-                                                                              '@'   => 'pron. dem.' }},
-                                               'art' => { 'poss' => { 'poss' => { 'definiteness' => { 'def' => 'art. hot.',
-                                                                                                      '@'   => 'art. poses.' }},
+                                               'dem' => { 'definite' => { 'def' => 'art. dem.',
+                                                                          '@'   => 'pron. dem.' }},
+                                               'art' => { 'poss' => { 'poss' => { 'definite' => { 'def' => 'art. hot.',
+                                                                                                  '@'   => 'art. poses.' }},
                                                                       '@'    => 'art. nehot.' }},
                                                '@'   => 'pronume' }},
                    'num'  => 'numeral',
                    'verb' => { 'verbtype' => { 'aux' => 'verb aux.',
-                                               '@'   => { 'verbform' => { 'inf'       => 'verb la infinitiv',
-                                                                          'fin'       => 'verb',
-                                                                          'inf|trans' => 'verb nepred.',
-                                                                          'trans'     => 'verb nepred.',
-                                                                          'ger'       => 'verb nepred.',
-                                                                          'part'      => 'verb la participiu' }}}},
+                                               '@'   => { 'verbform' => { 'inf'      => 'verb la infinitiv',
+                                                                          'fin'      => 'verb',
+                                                                          'inf|conv' => 'verb nepred.',
+                                                                          'trans'    => 'verb nepred.',
+                                                                          'ger'      => 'verb nepred.',
+                                                                          'part'     => 'verb la participiu' }}}},
                    'adv'  => 'adverb',
                    'adp'  => 'prepozitie',
                    'conj' => { 'conjtype' => { 'sub' => 'conj. aux.',
@@ -153,7 +153,7 @@ Lingua::Interset::Tagset::RO::Rdt - Driver for the tagset of the Romanian Depend
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -193,7 +193,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
