@@ -1,10 +1,10 @@
 # ABSTRACT: Driver for the Slovene tagset of the CoNLL 2006 Shared Task (derived from the Slovene Dependency Treebank).
-# Copyright © 2011, 2015 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2011, 2015, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::SL::Conll;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -171,7 +171,7 @@ sub _create_atoms
     # ANIMACY ####################
     $atoms{Animate} = $self->create_simple_atom
     (
-        'intfeature' => 'animateness',
+        'intfeature' => 'animacy',
         'simple_decode_map' =>
         {
             'yes' => 'anim',
@@ -353,10 +353,10 @@ sub _create_atoms
             'third'  => '3'
         }
     );
-    # NEGATIVENESS ####################
+    # POLARITY ####################
     $atoms{Negative} = $self->create_simple_atom
     (
-        'intfeature' => 'negativeness',
+        'intfeature' => 'polarity',
         'simple_decode_map' =>
         {
             'yes' => 'neg',
@@ -1281,7 +1281,7 @@ Lingua::Interset::Tagset::SL::Conll - Driver for the Slovene tagset of the CoNLL
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -1314,7 +1314,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
