@@ -1,11 +1,11 @@
 # ABSTRACT: Driver for the Slovene tagset of the Multext-EAST v4 project.
 # http://nlp.ffzg.hr/data/tagging/msd-hr.html
-# Copyright © 2015 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2015, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::SL::Multext;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -138,16 +138,16 @@ sub _create_feature_map
     my $self = shift;
     my %features =
     (
-        'N' => ['pos', 'nountype', 'gender', 'number', 'case', 'animateness'],
-        'V' => ['pos', 'verbtype', 'aspect', 'verbform', 'person', 'number', 'gender', 'negativeness'],
-        'A' => ['pos', 'adjtype', 'degree', 'gender', 'number', 'case', 'definiteness', 'animateness'],
+        'N' => ['pos', 'nountype', 'gender', 'number', 'case', 'animacy'],
+        'V' => ['pos', 'verbtype', 'aspect', 'verbform', 'person', 'number', 'gender', 'polarity'],
+        'A' => ['pos', 'adjtype', 'degree', 'gender', 'number', 'case', 'definite', 'animacy'],
         'P' => ['pos', 'prontype', 'person', 'gender', 'number', 'case', 'possnumber', 'possgender', 'clitic'],
         'R' => ['pos', 'adverb_type', 'degree'],
         'S' => ['pos', 'case'],
         # The documentation also mentions a third feature, "conjunction formation", with the values 's' (simple) and 'c' (compound).
         # It does not occur in the SETimes.HR corpus, there are only 'Cc' (coordinating conjunctions) and 'Cs' (subordinating).
         'C' => ['pos', 'conjtype'],
-        'M' => ['pos', 'numform', 'numtype', 'gender', 'number', 'case', 'animateness'],
+        'M' => ['pos', 'numform', 'numtype', 'gender', 'number', 'case', 'animacy'],
         'Q' => ['pos', 'parttype'],
         'X' => ['pos', 'restype']
     );
@@ -1346,7 +1346,7 @@ Lingua::Interset::Tagset::SL::Multext - Driver for the Slovene tagset of the Mul
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -1377,7 +1377,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
