@@ -1,11 +1,11 @@
 # ABSTRACT: Driver for the Mamba tagset of Swedish (Talbanken).
-# Copyright © 2006, 2015 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2006, 2015, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 # 25.1.2015: moved to the new object-oriented Interset
 
 package Lingua::Interset::Tagset::SV::Mamba;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -64,7 +64,7 @@ around BUILDARGS => sub
         'BV' => ['pos' => 'verb', 'other' => {'verb' => 'bliva'}],
         # EN Indefinite article or numeral "en", "ett" (one)
         # Examples: en, ett, 1
-        'EN' => ['pos' => 'adj|num', 'prontype' => 'art', 'definiteness' => 'ind'],
+        'EN' => ['pos' => 'adj|num', 'prontype' => 'art', 'definite' => 'ind'],
         # FV The verb "faa" (get)
         # Examples: får, få, fått, fick, finns
         'FV' => ['pos' => 'verb', 'other' => {'verb' => 'faa'}],
@@ -192,10 +192,10 @@ around BUILDARGS => sub
                                                                                                    '@'    => { 'other/nountype' => { 'adj' => 'AN',
                                                                                                                                      '@'   => 'NN' }}}},
                                                                           '@' => 'PO' }}}},
-                   'adj'  => { 'definiteness' => { 'ind' => 'EN',
-                                                   '@'   => 'AJ' }},
-                   'num'  => { 'definiteness' => { 'ind' => 'EN',
-                                                   '@'   => 'RO' }},
+                   'adj'  => { 'definite' => { 'ind' => 'EN',
+                                               '@'   => 'AJ' }},
+                   'num'  => { 'definite' => { 'ind' => 'EN',
+                                               '@'   => 'RO' }},
                    'verb' => { 'verbform' => { 'part' => { 'tense' => { 'pres' => 'SP',
                                                                         '@'    => 'TP' }},
                                                '@'    => { 'other/verb' => { 'vara'   => 'AV',
@@ -277,7 +277,7 @@ Lingua::Interset::Tagset::SV::Mamba - Driver for the Mamba tagset of Swedish (Ta
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -306,7 +306,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
