@@ -1,10 +1,10 @@
 # ABSTRACT: Driver for the Swedish PAROLE tagset.
-# Copyright © 2006-2009, 2015 Dan Zeman <zeman@ufal.mff.cuni.cz>
+# Copyright © 2006-2009, 2015, 2017 Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 package Lingua::Interset::Tagset::SV::Parole;
 use strict;
 use warnings;
-our $VERSION = '2.052';
+our $VERSION = '3.000';
 
 use utf8;
 use open ':utf8';
@@ -191,9 +191,9 @@ sub _create_atoms
         }
     );
     # 7. DEFINITENESS ####################
-    $atoms{definiteness} = $self->create_simple_atom
+    $atoms{definite} = $self->create_simple_atom
     (
-        'intfeature' => 'definiteness',
+        'intfeature' => 'definite',
         'simple_decode_map' =>
         {
             'D' => 'def',
@@ -293,11 +293,11 @@ sub _create_features_pos
     my $self = shift;
     my %features =
     (
-        'N' => ['gender', 'number', 'case', undef, 'definiteness', 'form'],
-        'A' => ['degree', 'gender', 'number', 'case', 'definiteness', 'form'],
+        'N' => ['gender', 'number', 'case', undef, 'definite', 'form'],
+        'A' => ['degree', 'gender', 'number', 'case', 'definite', 'form'],
         'D' => [undef,    'gender', 'number', undef, 'form'],
         'P' => [undef,    'gender', 'number', 'subjobj', undef, 'form'],
-        'M' => ['gender', 'number', 'case', 'definiteness', 'form'],
+        'M' => ['gender', 'number', 'case', 'definite', 'form'],
         'V' => ['verbform', 'tense', 'voice', 'form'],
         'R' => ['degree', 'form'],
         'S' => ['form'],
@@ -567,7 +567,7 @@ Lingua::Interset::Tagset::SV::Parole - Driver for the Swedish PAROLE tagset.
 
 =head1 VERSION
 
-version 2.052
+version 3.000
 
 =head1 SYNOPSIS
 
@@ -597,7 +597,7 @@ Dan Zeman <zeman@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Univerzita Karlova v Praze (Charles University in Prague).
+This software is copyright (c) 2017 by Univerzita Karlova (Charles University).
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
